#
# spec file for package pw3270
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) <2008> <Banco do Brasil S.A.>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

#---[ Versions ]------------------------------------------------------------------------------------------------------

%define MAJOR_VERSION 5
%define MINOR_VERSION 2

%define _libvrs %{MAJOR_VERSION}_%{MINOR_VERSION}

#---[ Selected modules ]----------------------------------------------------------------------------------------------

%define _dbus           1
%define _help2man       1

#---[ Packaging ]-----------------------------------------------------------------------------------------------------

Name:           pw3270
Version:        5.2
Release:        lp152.2.21
Summary:        IBM 3270 Terminal emulator for GTK
License:        GPL-2.0
Group:          System/X11/Terminals
Url:            https://portal.softwarepublico.gov.br/social/pw3270/

Source:         pw3270-%{version}.tar.xz
Patch0:         reproducible.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Requires:       shared-mime-info
Requires:       %{name}-branding >= 5.2

#--[ Setup by distribution ]------------------------------------------------------------------------------------------
# 
# References:
#
# https://en.opensuse.org/openSUSE:Build_Service_cross_distribution_howto#Detect_a_distribution_flavor_for_special_code
#

#--[ Red HAT ]--------------------------------------------------------------------------------------------------------

%if 0%{?rhel_version}

%define _help2man       0

BuildRequires:  dbus-devel
BuildRequires:  dbus-glib-devel
BuildRequires:  gtk3-devel
BuildRequires:  lib3270-devel
BuildRequires:  librsvg2-tools
BuildRequires:  libv3270-devel
BuildRequires:  openssl-devel

%endif

#--[ CentOS ]---------------------------------------------------------------------------------------------------------

%if 0%{?centos_version}

%define _help2man       0

BuildRequires:  dbus-devel
BuildRequires:  dbus-glib-devel
BuildRequires:  gtk3-devel
BuildRequires:  lib3270-devel
BuildRequires:  librsvg2-tools
BuildRequires:  libv3270-devel
BuildRequires:  openssl-devel

# CENTOS Genmarshal doesn't depends on python!
BuildRequires:	python

%endif

#--[ Fedora ]---------------------------------------------------------------------------------------------------------

%if 0%{?fedora}

BuildRequires:  autoconf-archive
BuildRequires:  pkgconfig(lib3270)
BuildRequires:  pkgconfig(libv3270)
BuildRequires:  librsvg2-tools
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(openssl)

%endif

#--[ SuSE ]-----------------------------------------------------------------------------------------------------------

%if 0%{?suse_version}

BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(lib3270)
BuildRequires:  pkgconfig(libv3270)
BuildRequires:  pkgconfig(openssl)

# https://en.opensuse.org/openSUSE:Build_Service_cross_distribution_howto
BuildRequires:  update-desktop-files
%if 0%{suse_version} >= 1210
BuildRequires:	autoconf-archive
%endif
%if 0%{suse_version} >= 1550 || 0%{?sle_version} >= 150200
BuildRequires:  rsvg-convert
%else
BuildRequires:  rsvg-view
%endif

%endif

#---------------------------------------------------------------------------------------------------------------------

BuildRequires:  ImageMagick
BuildRequires:  autoconf >= 2.61
BuildRequires:  automake
BuildRequires:  binutils
BuildRequires:  coreutils
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  findutils
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  m4
BuildRequires:  optipng
BuildRequires:  pkgconfig
BuildRequires:  sed

%if 0%{?_help2man}
BuildRequires:  help2man
%endif

%description
GTK-based IBM 3270 terminal emulator with many advanced features. It can be used to communicate with any IBM host that supports 3270-style connections over TELNET.

Based on the original x3270 code, pw3270 was originally created for Banco do Brasil, and is now used worldwide.

#--[ Application library ]--------------------------------------------------------------------------------------------

%package -n libpw3270-%{_libvrs}
Summary:        3270 terminal emulation library
Group:          System/Libraries

%description -n libpw3270-%{_libvrs}
GTK-based IBM 3270 terminal emulator with many advanced features. It can be used to communicate with any IBM host that supports 3270-style connections over TELNET.

This package contains the plugin support library.

#--[ Configuration & Branding ]---------------------------------------------------------------------------------------

%package branding
Summary:        Configuration and branding for %{name}
Group:          System/X11/Terminals
Requires:       %{name} = %{version}
Conflicts:      %{name}-config
Provides:       %{name}-config = %{version}

%description branding
GTK-based IBM 3270 terminal emulator with many advanced features. It can be used to communicate with any IBM host that supports 3270-style connections over TELNET.

This package contains the default configuration and branding for %{name}.

#--[ Devel ]----------------------------------------------------------------------------------------------------------

%package devel
Summary:        Files required for development of %{name} plugins
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libpw3270-%{_libvrs}
Requires:       pkgconfig(gtk+-3.0)
Requires:       pkgconfig(lib3270)
Requires:       pkgconfig(libv3270)

%description -n %{name}-devel
GTK-based IBM 3270 terminal emulator with many advanced features. It can be used to communicate with any IBM host that supports 3270-style connections over TELNET.

This package contains the development files for %{name}.

#---[ Build & Install ]-----------------------------------------------------------------------------------------------

%prep

%setup -q -n pw3270-%{version}
%patch0 -p1

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
NOCONFIGURE=1 ./autogen.sh

%configure \
        --with-release=%{release}
make %{?_smp_mflags} clean

# parallel build is broken
make all -j1

%install
%make_install

%find_lang pw3270 langfiles

%fdupes %{buildroot}/%{_prefix}

#---[ Files ]---------------------------------------------------------------------------------------------------------

%files -f langfiles
%license LICENSE
%doc AUTHORS README.md
%if 0%{?_help2man}
%{_mandir}/*/*
%endif

# Main application
%dir %{_datadir}/pw3270
%dir %{_datadir}/pw3270/ui
%dir %{_datadir}/pw3270/charsets
%dir %{_libdir}/pw3270-plugins

%{_bindir}/pw3270
%{_datadir}/pw3270/charsets/bracket.xml

%files -n libpw3270-%{_libvrs}
%{_libdir}/libpw3270.so.%{MAJOR_VERSION}.%{MINOR_VERSION}

%files branding

%{_datadir}/applications/pw3270.desktop
%{_datadir}/pw3270/ui/00default.xml
%{_datadir}/pw3270/ui/10functions.xml
%{_datadir}/pw3270/ui/10keypad.xml
%{_datadir}/pw3270/colors.conf
%{_datadir}/pw3270/pw3270.png
%{_datadir}/pw3270/pw3270-logo.png
%{_datadir}/pixmaps/pw3270.png

%files devel

%{_includedir}/pw3270.h
%{_includedir}/pw3270cpp.h
%{_includedir}/pw3270

%{_libdir}/libpw3270.so

%{_libdir}/libpw3270cpp.a
%{_libdir}/pkgconfig/pw3270.pc
%{_datadir}/pw3270/locale

%{_datadir}/pw3270/ui/98trace.xml
%{_datadir}/pw3270/ui/99debug.xml

#---[ Scripts ]-------------------------------------------------------------------------------------------------------

%post   -n libpw3270-%{_libvrs} -p /sbin/ldconfig
%postun -n libpw3270-%{_libvrs} -p /sbin/ldconfig

%changelog
* Wed Mar 25 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to make package build reproducible (boo#1047218)
* Thu Feb 20 2020 Max Lin <mlin@suse.com>
- Leap 15.2 and SLE15 SP2 has newer librsvg, extend the conditional
  for "BuildRequires: rsvg-convert"
* Wed Oct 23 2019 ro@suse.de
- fix build-requires for factory/tumbleweed
  rsvg-convert tool is now in rsvg-convert package
* Fri May 31 2019 perry.werneck@gmail.com
  * Doing a "clean exit" on SIGTERM.
  * Updating translation.
  * Updating translation.
  * Fixing save message.
  * Fixing the application name with ./configure option.
  * Showing message on configuration update.
  * Updating rpm packaging.
  * Fixing icon and application name.
  * Adding desktop file.
  * Creating application icon in standard folder.
  * Emitting message when the logo is not available on about window.
  * Fixing memory allocation error on about dialog.
  * Fixing bug in about window detected on windows version.
  * Fixing win32 runtime.
  * Updating read me.
  * Updating versions in win packate.
  * Fixing file version indication in win32 package.
  * Fixing windows build.
  * Removing windows native dialog.
  * Fixing windows build.
  * Removing unused sources.
  * Adding compiled version of the schemas in the runtime package.
  * Adding gtkfilechooser schema to runtime package.
  * Comentando fontes do código que foi transferido para a libv3270.
  * Adding script to build and install lib3270 and libv3270 on msys2
  * Fixing msys2 build.
  * Disabling unused code.
  * Updating translations.
  * Renaming application transfer file dialog to avoid conflicts.
  * Updating package control file.
* Tue Feb 26 2019 perry.werneck@gmail.com
- Update to version 5.2:
  * Updating linux packages.
  * Removing libv3270 submodule
  * Updating branding Makefile.
  * Updating autogen
  * Updating project.
  * Fixing RHEL 7 builds.
  * Removing unused UI files.
  * Fixing .deb builds
  * Fixing RHEL7 build.
  * Updating linux package.
* Thu Sep 14 2017 jengelh@inai.de
- Put libpw3270 into its own package (shared library guideline).
- Drop require on /usr/bin/openssl, this is unusual for a library
  to request.
- %%configure already sets CFLAGS,CXXFLAGS, do not set it again.
  Replace old RPM variables. Remove redundant %%clean section.
  Do not run fdupes across hardlink boundaries.
- Fix one RPM category. Trim redundant words from description.
* Wed Sep 13 2017 erico.mendonca@suse.com
- fix_actions.patch: patch is no longer necessary.
- keypad_update.patch: patch is no longer necessary.
- mutex_include.patch: patch is no longer necessary.
- gtk2-fixes.patch: patch is no longer necessary.
- file_chooser.patch: patch is no longer necessary.
- fix_oorexx_charset.patch: patch is no longer necessary.
* Wed Sep 13 2017 perry.werneck@gmail.com
- Updating to the latest git level, closing package for distribution.
- Java, Rexx, PHP, Mono and other extensions for scripting are now separated packages.
* Thu Jan 26 2017 perry.werneck@gmail.com
- Fixing .deb builds.
* Thu Jan 19 2017 perry.werneck@gmail.com
- Removing unused sources, refactoring Makefiles, build & installation
* Tue Dec 27 2016 perry.werneck@gmail.com
- Updating deb dependencies.
* Fri Nov  4 2016 perry.werneck@gmail.com
- Fixing PHP5 requires.
* Fri Oct 21 2016 perry.werneck@gmail.com
- Fixing script file chooser
- added patches:    fix_oorexx_charset.patch
    mutex_include.patch
    keypad_update.patch
    file_chooser.patch
    fix_actions.patch
    gtk2-fixes.patch
* Fri Oct 21 2016 perry.werneck@gmail.com
- Fixing charset problem on ooRexx plugin
* Fri Oct 21 2016 perry.werneck@gmail.com
- Fixing backport for bug 998842 (https://bugzilla.suse.com/show_bug.cgi?id=998842)
    on OpenSUSE 13.2
* Thu Oct 20 2016 perry.werneck@gmail.com
- Adding PHP5 support on Debian builds
* Wed Oct 19 2016 perry.werneck@gmail.com
- Fixing gtk2 builds.
